Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nodejs/node.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'deps/v8/src/objects/debug-objects.h')
-rw-r--r--deps/v8/src/objects/debug-objects.h10
1 files changed, 4 insertions, 6 deletions
diff --git a/deps/v8/src/objects/debug-objects.h b/deps/v8/src/objects/debug-objects.h
index 749489a1c1d..3b94a4e46e2 100644
--- a/deps/v8/src/objects/debug-objects.h
+++ b/deps/v8/src/objects/debug-objects.h
@@ -45,8 +45,8 @@ class DebugInfo : public Struct, public NeverReadOnlySpaceObject {
// Bit field containing various information collected for debugging.
DECL_INT_ACCESSORS(debugger_hints)
- // Function identifier field from shared function info.
- DECL_ACCESSORS(function_identifier, Object)
+ // Script field from shared function info.
+ DECL_ACCESSORS(script, Object)
// DebugInfo can be detached from the SharedFunctionInfo iff it is empty.
bool IsEmpty() const;
@@ -168,10 +168,8 @@ class DebugInfo : public Struct, public NeverReadOnlySpaceObject {
static const int kSharedFunctionInfoOffset = Struct::kHeaderSize;
static const int kDebuggerHintsOffset =
kSharedFunctionInfoOffset + kPointerSize;
- static const int kFunctionIdentifierOffset =
- kDebuggerHintsOffset + kPointerSize;
- static const int kOriginalBytecodeArrayOffset =
- kFunctionIdentifierOffset + kPointerSize;
+ static const int kScriptOffset = kDebuggerHintsOffset + kPointerSize;
+ static const int kOriginalBytecodeArrayOffset = kScriptOffset + kPointerSize;
static const int kBreakPointsStateOffset =
kOriginalBytecodeArrayOffset + kPointerSize;
static const int kFlagsOffset = kBreakPointsStateOffset + kPointerSize;